@@ -29,6 +29,18 @@ class Sentiment(ClassifierI):
         conf = choice_votes / len(votes)
         return conf
 
+def find_features(document):
+    words = word_tokenize(document)
+    features = {}
+    k = open('all_words.pickle','rb')
+    all_words = pickle.load(k)
+    k.close()
+    all_words = nltk.FreqDist(all_words)
+    word_features = list(all_words.keys())[:5000]
+    for w in word_features:
+        features[w] = (w in words)
+    return features
+
 def load_model(file_path): 
     classifier_f = open(file_path, "rb")
     classifier = pickle.load(classifier_f)
@@ -38,16 +50,13 @@ def load_model(file_path):
 def sentiment(text):
     MNB_Clf = load_model('MNB_clf.pickle')
     ensemble_clf = Sentiment(MNB_Clf) 
-    feature_list = [f[0] for f in testing_set]
-    ensemble_preds = [ensemble_clf.classify(features) for features in feature_list]
     feats = find_features(text)
     return ensemble_clf.classify(feats), ensemble_clf.confidence(feats)
-
+import sys
 def main():
-    try:
-        sent = sys.argv[1]
-        print(sentiment(sent)) 	
-    except:
-        print("Exception occurred")
+    sent = sys.argv[1]
+    dic = {'pos':'positive','neg':'negative'}
+    print("My experience says that the text is "+dic[sentiment(sent)[0]])
+
 if __name__=="__main__":
     main()
\ No newline at end of file
